#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path
version:              0.8.0
visibility:           public
id:                   path-0.8.0-7heFkhncrSTDEqYwDMG3OT
key:                  path-0.8.0-7heFkhncrSTDEqYwDMG3OT
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  f8b8b52dd826db452ee619280192e9b9
exposed:              True
exposed-modules:      Path Path.Internal Path.Posix Path.Windows
import-dirs:          /usr/lib/ghc-8.10.3/site-local/path-0.8.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/path-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.3/path-0.8.0
hs-libraries:         HSpath-0.8.0-7heFkhncrSTDEqYwDMG3OT
depends:
    aeson-1.5.5.1-9jeVsPSyrWB7SomB2C4Dbq base-4.14.1.0 deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1
    hashable-1.3.0.0-1CyJarTczNyI67reXuzvxw template-haskell-2.16.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

